@@ -1,4 +1,5 @@
 import logging
+from functools import wraps
 
 from requests.exceptions import RequestException
 
@@ -6,15 +7,16 @@ from requests.exceptions import RequestException
 logger = logging.getLogger(__name__)
 
 
-def except_shell(errors=(Exception,), default_value=''):
+def except_shell(errors=(Exception,)):
     def decorator(func):
-        def new_func(*args, **kwargs):
+        @wraps(func)
+        def wrapper(*args, **kwargs):
             try:
                 return func(*args, **kwargs)
             except errors as e:
                 logging.error(e)
-                return default_value or None
-        return new_func
+                return None
+        return wrapper
     return decorator
 
 
