@@ -1,5 +1,7 @@
+from json import dumps
+from hashlib import md5
 from django.conf import settings
-from rest_framework.permissions import IsAuthenticated
+from rest_framework.permissions import IsAuthenticated, IsAdminUser
 
 
 class HasApiKeyOrIsAuthenticated(IsAuthenticated):
@@ -10,4 +12,3 @@ class HasApiKeyOrIsAuthenticated(IsAuthenticated):
             if token[0] == settings.API_KEY_HEADER and token[1] == settings.API_KEY:
                 return True
         return super().has_permission(request, view)
-
